@@ -110,8 +110,6 @@ tufte_html_book = function(...) {
 #'   (the i-th figure/table); if \code{FALSE}, figures/tables will be numbered
 #'   sequentially in the document from 1, 2, ..., and you cannot cross-reference
 #'   section headers in this case.
-#' @param clean_highlight_tags Whether to remove the \verb{<div>} tags around
-#'   \verb{<pre>}, and clean up \verb{<a>} on all lines in code blocks.
 #' @inheritParams pdf_book
 #' @return An R Markdown output format object to be passed to
 #'   \code{rmarkdown::\link{render}()}.
@@ -123,8 +121,7 @@ tufte_html_book = function(...) {
 #' @references \url{https://bookdown.org/yihui/bookdown/}
 #' @export
 html_document2 = function(
-  ..., number_sections = TRUE, pandoc_args = NULL, base_format = rmarkdown::html_document,
-  clean_highlight_tags = TRUE
+  ..., number_sections = TRUE, pandoc_args = NULL, base_format = rmarkdown::html_document
 ) {
   base_format = get_base_format(base_format)
   config = base_format(
@@ -137,7 +134,6 @@ html_document2 = function(
     x = restore_appendix_html(x, remove = FALSE)
     x = restore_part_html(x, remove = FALSE)
     x = resolve_refs_html(x, global = !number_sections)
-    if (clean_highlight_tags) x = clean_pandoc2_highlight_tags(x)
     write_utf8(x, output)
     output
   }
@@ -267,7 +263,6 @@ split_chapters = function(output, build = build_chapter, number_sections, split_
   x = add_section_ids(x)
   x = restore_part_html(x)
   x = restore_appendix_html(x)
-  x = clean_pandoc2_highlight_tags(x)
 
   # no (or not enough) tokens found in the template
   if (any(c(i1, i2, i3, i4, i5, i6) == 0)) {
@@ -1008,15 +1003,6 @@ restore_math_labels = function(x) {
   x
 }
 
-# remove the <div> tags around <pre>, and clean up <a> on all lines
-clean_pandoc2_highlight_tags = function(x) {
-  if (!pandoc2.0()) return(x)
-  x = gsub('(</a></code></pre>)</div>', '\\1', x)
-  x = gsub('<div class="sourceCode"[^>]+>(<pre)', '\\1', x)
-  x = gsub('<a class="sourceLine"[^>]+>(.*)</a>', '\\1', x)
-  x
-}
-
 # extract a chapter title from the body, and prepend it to the page <title>
 prepend_chapter_title = function(head, body) {
   r1 = '(.*?<title>)(.+?)(</title>.*)'
